@@ -298,20 +298,26 @@ class HeaderResolver(object):
             if column.__class__ is PlateColumn:
                 append.append(StringColumn(PLATE_NAME_COLUMN, '',
                               self.DEFAULT_COLUMN_SIZE, list()))
+                column.name = "Plate"
             if column.__class__ is WellColumn:
                 append.append(StringColumn(WELL_NAME_COLUMN, '',
                               self.DEFAULT_COLUMN_SIZE, list()))
+                column.name = "Well"
             if column.__class__ is ImageColumn:
                 append.append(StringColumn(IMAGE_NAME_COLUMN, '',
                               self.DEFAULT_COLUMN_SIZE, list()))
-            # Currently hard-coded, but "if image name, then add image id"
-            if column.name == IMAGE_NAME_COLUMN:
-                append.append(ImageColumn("Image", '', list()))
+                # Ensure ImageColumn is named "Image"
+                column.name = "Image"
             if column.__class__ is RoiColumn:
                 append.append(StringColumn(ROI_NAME_COLUMN, '',
                               self.DEFAULT_COLUMN_SIZE, list()))
+                # Ensure RoiColumn is named 'Roi'
+                column.name = "Roi"
+            # If image/roi name, then add ID column"
+            if column.name == IMAGE_NAME_COLUMN:
+                append.append(ImageColumn("Image", '', list()))
             if column.name == ROI_NAME_COLUMN:
-                append.append(RoiColumn("roi", '', list()))
+                append.append(RoiColumn("Roi", '', list()))
         if self.columns_sanity_check(columns):
             columns.extend(append)
         return columns
@@ -896,7 +902,7 @@ class ImageWrapper(ValueWrapper):
         return self.rois_by_name[rname].id.val
 
     def get_roi_name_by_id(self, rid):
-        return self.rois_by_id[rid].name.val
+        return unwrap(self.rois_by_id[rid].name)
 
     def resolve_roi(self, column, row, value):
         try:
@@ -940,10 +946,10 @@ class ImageWrapper(ValueWrapper):
         for roi in data:
             rid = roi.id.val
             rois_by_id[rid] = roi
-            if roi.name.val in rois_by_name.keys():
+            if unwrap(roi.name) in rois_by_name.keys():
                 log.warn('Conflicting ROI names.')
                 self.ambiguous_naming = True
-            rois_by_name[roi.name.val] = roi
+            rois_by_name[unwrap(roi.name)] = roi
         self.rois_by_id = rois_by_id
         self.rois_by_name = rois_by_name
         log.debug('Completed parsing image: %s' % self.target_name)
@@ -1174,11 +1180,11 @@ class ParsingContext(object):
             for column in self.columns:
                 if not values:
                     if isinstance(column, ImageColumn) or \
+                       isinstance(column, RoiColumn) or \
                        column.name in (PLATE_NAME_COLUMN,
                                        WELL_NAME_COLUMN,
                                        IMAGE_NAME_COLUMN,
-                                       ROI_NAME_COLUMN,
-                                       'roi'):
+                                       ROI_NAME_COLUMN):
                         # Then assume that the values will be calculated
                         # later based on another column.
                         continue
@@ -1397,6 +1403,8 @@ class ParsingContext(object):
                     log.debug(roi_column)
                     rid = roi_column.values[i]
                     rname = self.value_resolver.get_roi_name_by_id(rid)
+                    if rname is None:
+                        rname = ""
                 except KeyError:
                     log.warn(
                         "%d not found in roi ids" % rid)
